@@ -78,7 +78,6 @@ install_dev_tools(){
         # emacs \
         # byobu \
         # multitail  # Set the terminal with red letters build the docker
-
     sudo pip install -q \
         ipython \
         py-spy \
@@ -89,6 +88,14 @@ install_dev_tools(){
         pg-activity \
         nodeenv \
         pdbpp
+
+    # Symlinks used by vscode and possibly other tools.
+    PCV_DIR="$(python3 -c "import pre_commit_vauxoo as pcv; print(pcv.__path__[0])")/cfg"
+    ln -sf "${PCV_DIR}/.pylintrc" "${HOME}/.pylintrc"
+    ln -sf "${PCV_DIR}/.flake8" "${HOME}/.flake8"
+    ln -sf "${PCV_DIR}/.isort.cfg" "${HOME}/.isort.cfg"
+    ln -sf "${PCV_DIR}/.eslintrc.json" "${HOME}/.eslintrc.json"
+
     # pre install pre-commit-vauxoo?
     # sudo su odoo -c "git init /tmp/test && cd /tmp/test && pre-commit-vauxoo -f"
     touch /home/odoo/full_test-requirements.txt
@@ -125,10 +132,14 @@ EOF
     # Configure emacs for odoo user
     git clone --depth 1 -b master https://github.com/Vauxoo/emacs.d.git /home/odoo/.emacs.d
     chown -R odoo:odoo /home/odoo/.emacs.d
-
-    # TODO: Install custom vim?
 }
 
+setup_coverage() {
+  echo "export MODULES2TEST=$(cd ${MAIN_REPO_FULL_PATH} && find * -name "__manifest__.py" -printf "/%h,")" >> ${HOME}/.bashrc
+  echo "export MODULES2INSTALL=$(cd ${MAIN_REPO_FULL_PATH} && find * -name "__manifest__.py" -printf "%h,")" >> ${HOME}/.bashrc
+}
+
+
 bash_colorized(){
     cat >> ~/.bashrc << 'EOF'
 Purple="\[\033[0;35m\]"
@@ -184,11 +195,12 @@ configure_vim(){
 
     if [ -z ${VIM_INSTALL+x} ];
     then
-      echo "VIM_INSTALL is not defined. Skipping vim installation."
+      echo "VIM_INSTALL is not defined. Skipping vim configuration (spf13 and other plugins). Use --build-ev-args=VIM_INSTALL for vim to be autoconfigured."
       return 0;
     fi
     # Upgrade & configure vim
     apt install vim --only-upgrade
+    apt install exuberant-ctags -y
     # Get vim version
     VIM_VERSION=$(dpkg -s vim | grep Version | sed -n 's/.*\([0-9]\+\.[0-9]\+\)\..*/\1/p' | sed -r 's/\.//g')
 
@@ -220,7 +232,7 @@ EOF
 
     # Install and configure YouCompleteMe
     VIM_YOUCOMPLETEME_PATH="${HOME}/.vim/bundle/YouCompleteMe"
-    git clone "https://github.com/Valloric/YouCompleteMe.git" ${VIM_YOUCOMPLETEME_PATH} -d 1
+    git clone "https://github.com/Valloric/YouCompleteMe.git" ${VIM_YOUCOMPLETEME_PATH} --depth 1
     # Install the custom version of YouCompleteMe because the last required g++ 4.9
     (cd "${VIM_YOUCOMPLETEME_PATH}" && git reset --hard c31152d34591f3211799ca1fe918eb78487e6dde && git submodule update --init --recursive && ./install.py)
     cat >> ${HOME}/.vimrc << EOF
